# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

from .translation import Translation as Translation
from .transcription import Transcription as Transcription
from .translation_create_params import (
    TranslationCreateParams as TranslationCreateParams,
)
from .transcription_create_params import (
    TranscriptionCreateParams as TranscriptionCreateParams,
)



# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .._types import FileTypes

__all__ = ["FileCreateParams"]


class FileCreateParams(TypedDict, total=False):
    file: Required[FileTypes]
    """The file object (not file name) to be uploaded.

    If the `purpose` is set to "fine-tune", the file will be used for fine-tuning.
    """

    purpose: Required[str]
    """The intended purpose of the uploaded file.

    Use "fine-tune" for
    [fine-tuning](https://platform.openai.com/docs/api-reference/fine-tuning). This
    allows us to validate the format of the uploaded file is correct for
    fine-tuning.
    """



# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

from .chat_completion import ChatCompletion as ChatCompletion
from .chat_completion_role import ChatCompletionRole as ChatCompletionRole
from .chat_completion_chunk import ChatCompletionChunk as ChatCompletionChunk
from .chat_completion_message import ChatCompletionMessage as ChatCompletionMessage
from .completion_create_params import CompletionCreateParams as CompletionCreateParams
from .chat_completion_message_param import (
    ChatCompletionMessageParam as ChatCompletionMessageParam,
)



# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["ChatCompletionMessageParam", "FunctionCall"]


class FunctionCall(TypedDict, total=False):
    arguments: Required[str]
    """
    The arguments to call the function with, as generated by the model in JSON
    format. Note that the model does not always generate valid JSON, and may
    hallucinate parameters not defined by your function schema. Validate the
    arguments in your code before calling your function.
    """

    name: Required[str]
    """The name of the function to call."""


class ChatCompletionMessageParam(TypedDict, total=False):
    content: Required[Optional[str]]
    """The contents of the message.

    `content` is required for all messages, and may be null for assistant messages
    with function calls.
    """

    role: Required[Literal["system", "user", "assistant", "function"]]
    """The role of the messages author.

    One of `system`, `user`, `assistant`, or `function`.
    """

    function_call: FunctionCall
    """
    The name and arguments of a function that should be called, as generated by the
    model.
    """

    name: str
    """The name of the author of this message.

    `name` is required if role is `function`, and it should be the name of the
    function whose response is in the `content`. May contain a-z, A-Z, 0-9, and
    underscores, with a maximum length of 64 characters.
    """



# File generated from our OpenAPI spec by Stainless.

from typing import Optional

from .._models import BaseModel

__all__ = ["FileObject"]


class FileObject(BaseModel):
    id: str
    """The file identifier, which can be referenced in the API endpoints."""

    bytes: int
    """The size of the file in bytes."""

    created_at: int
    """The Unix timestamp (in seconds) for when the file was created."""

    filename: str
    """The name of the file."""

    object: str
    """The object type, which is always "file"."""

    purpose: str
    """The intended purpose of the file. Currently, only "fine-tune" is supported."""

    status: Optional[str] = None
    """
    The current status of the file, which can be either `uploaded`, `processed`,
    `pending`, `error`, `deleting` or `deleted`.
    """

    status_details: Optional[str] = None
    """Additional details about the status of the file.

    If the file is in the `error` state, this will include a message describing the
    error.
    """



# File generated from our OpenAPI spec by Stainless.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel
from ..completion_usage import CompletionUsage
from .chat_completion_message import ChatCompletionMessage

__all__ = ["ChatCompletion", "Choice"]


class Choice(BaseModel):
    finish_reason: Literal["stop", "length", "function_call", "content_filter"]
    """The reason the model stopped generating tokens.

    This will be `stop` if the model hit a natural stop point or a provided stop
    sequence, `length` if the maximum number of tokens specified in the request was
    reached, `content_filter` if content was omitted due to a flag from our content
    filters, or `function_call` if the model called a function.
    """

    index: int
    """The index of the choice in the list of choices."""

    message: ChatCompletionMessage
    """A chat completion message generated by the model."""


class ChatCompletion(BaseModel):
    id: str
    """A unique identifier for the chat completion."""

    choices: List[Choice]
    """A list of chat completion choices.

    Can be more than one if `n` is greater than 1.
    """

    created: int
    """The Unix timestamp (in seconds) of when the chat completion was created."""

    model: str
    """The model used for the chat completion."""

    object: str
    """The object type, which is always `chat.completion`."""

    usage: Optional[CompletionUsage] = None
    """Usage statistics for the completion request."""
